if select(2, UnitClass("player")) ~= "PALADIN" then
	return DisableAddOn("HolyPowerIndicator")
end

HolyPowerIndicator = LibStub("AceAddon-3.0"):NewAddon("HolyPowerIndicator", "AceEvent-3.0")

local textures = {
		["Number"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\Number\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\Number\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\Number\\3",
		},
		["Alliance"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\Alliance\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\Alliance\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\Alliance\\3",
		},
		["Horde"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\Horde\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\Horde\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\Horde\\3",
		},
		["Dot"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\Dot\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\Dot\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\Dot\\3",
		},
		["Coins"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\Coins\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\Coins\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\Coins\\3",
		},
		["Bar"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\Bar\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\Bar\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\Bar\\3",
		},
		["PvPRank"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\PvPRank\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\PvPRank\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\PvPRank\\3",
		},
		["TukBar"] = {
			"Interface\\AddOns\\HolyPowerIndicator\\TukBar\\1",
			"Interface\\AddOns\\HolyPowerIndicator\\TukBar\\2",
			"Interface\\AddOns\\HolyPowerIndicator\\TukBar\\3",
		},
}

do
	local frame = CreateFrame("Frame", "HolyPowerIndicatorFrame", UIParent)
	frame:SetMovable(true)
	frame:SetUserPlaced(true)
	frame:SetPoint("CENTER")
	frame:SetWidth(128)
	frame:SetHeight(128)

	local texture = frame:CreateTexture(nil, "ARTWORK")
	texture:SetAllPoints(frame)

	HolyPowerIndicator.frame = frame

	frame.texture = texture
end

function HolyPowerIndicator:OnInitialize()
	local defaults = {
		profile = {
			locked = true,
			alpha = 1,
			scale = 1,
			textureSelect = "TukBar",
		},
	}

	self.db = LibStub("AceDB-3.0"):New("HolyPowerIndicatorDB", defaults, "Default")

	local options = {
		name = "HolyPowerIndicator",
		type ="group",
		args = {
			locked = {
				type = "toggle",
				name = "Lock frame",
				desc = "Locks the Holy Power frame.",
				width = "full",
				order = 1,
				get = function() return HolyPowerIndicator.db.profile.locked end,
				set = function(_, value)
						HolyPowerIndicator.db.profile.locked = value
						HolyPowerIndicator:ToggleFrameLock(value)
					end,
			},
			alpha = {
				type = "range",
				name = "Frame opacity",
				desc = "Set the frame's opacity.",
				width = "full",
				min = 0.1,
				max = 1,
				step = 0.1,
				order = 2,
				get = function() return HolyPowerIndicator.db.profile.alpha end,
				set = function(_, value) 
						HolyPowerIndicator.db.profile.alpha = value
						HolyPowerIndicator.frame:SetAlpha(value)
					end,
			},
			scale = {
				type = "range",
				name = "Frame scale",
				desc = "Set the frame's scale.",
				width = "full",
				min = 0.2,
				max = 5,
				step = 0.2,
				order = 3,
				get = function() return HolyPowerIndicator.db.profile.scale end,
				set = function(_, value) 
						HolyPowerIndicator.db.profile.scale = value
						HolyPowerIndicator.frame:SetScale(value) 
					end,
			},
			textureSelect = {
				type = "select",
				name = "Texture",
				desc = "Select the texture.",
				width = "full",
				values = {
					["Alliance"] = "Alliance",
					["Bar"] = "Bar",
					["Coins"] = "Coins",
					["Dot"] = "Dot",
					["Horde"] = "Horde",
					["Number"] = "Number",
					["PvPRank"] = "PvPRank",
					["TukBar"] = "TukBar",
				},
				get = function() return HolyPowerIndicator.db.profile.textureSelect end,
				set= function(_, value) 
						HolyPowerIndicator.db.profile.textureSelect = value
					end,
			},
		},
	}

	LibStub("AceConfigRegistry-3.0"):RegisterOptionsTable("HolyPowerIndicator", options)
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("HolyPowerIndicator", "HolyPowerIndicator")

	PaladinPowerBar:SetAlpha(0)

	self.frame:SetAlpha(self.db.profile.alpha)
	self.frame:SetScale(self.db.profile.scale)
	self:ToggleFrameLock(self.db.profile.locked)

	SLASH_HOLYPOWERINDICATOR1 = "/hpi"
	SlashCmdList["HOLYPOWERINDICATOR"] = function(msg)
		if msg == "lock" then
			self:ToggleFrameLock()
		else
			InterfaceOptionsFrame_OpenToCategory(self.optionsFrame)
		end
	end

	self:RegisterEvent("UNIT_POWER")
end

function HolyPowerIndicator:ToggleFrameLock(value)
	if value ~= nil then
		value = self.db.profile.locked
	end

	local frame = self.frame

	if value then
		frame:EnableMouse(false)
		frame:RegisterForDrag(nil)
		frame:SetScript("OnDragStart", nil)
		frame:SetScript("OnDragStop", nil)
		if UnitPower("player", 9) == 0 then
			frame:Hide()
		end

	else
		frame:EnableMouse(true)
		frame:RegisterForDrag("LeftButton")
		frame:SetScript("OnDragStart", frame.StartMoving)
		frame:SetScript("OnDragStop", frame.StopMovingOrSizing)
		if UnitPower("player", 9) == 0 then
			frame.texture:SetTexture(textures[self.db.profile.textureSelect][3])
			frame:Show()
		end
	end

	self.db.profile.locked = value
end

function HolyPowerIndicator:UNIT_POWER(event, unit, powerType)
	if unit == "player" and powerType == "HOLY_POWER" then
		local power = UnitPower("player", 9)
		if power > 0 then
			self.frame.texture:SetTexture(textures[self.db.profile.textureSelect][power])
			self.frame:Show()
		else
			self.frame:Hide()
		end
	end
end
